@@ -1,6 +1,6 @@
 package Dist::Zilla::Plugin::JSAN;
 BEGIN {
-  $Dist::Zilla::Plugin::JSAN::VERSION = '0.01';
+  $Dist::Zilla::Plugin::JSAN::VERSION = '0.02';
 }
 
 # ABSTRACT: a plugin for Dist::Zilla for building JSAN distributions
@@ -12,14 +12,8 @@ use Moose::Autobox;
 use Path::Class;
 use Dist::Zilla::File::InMemory;
 
-extends 'Dist::Zilla::Plugin::ModuleBuild';
-
-
-has 'mb_class' => (
-    isa => 'Str',
-    is  => 'rw',
-    default => 'Module::Build::JSAN::Installable',
-);
+with 'Dist::Zilla::Role::FileGatherer';
+with 'Dist::Zilla::Role::BuildRunner';
 
 
 has 'docs_markup' => (
@@ -29,124 +23,15 @@ has 'docs_markup' => (
 );
 
 
-has 'static_dir' => (
-    isa     => 'Str',
-    is      => 'rw',
-    default => 'static'
-);
-
-
-sub _use_custom_class {
-    my ($self) = @_;
-    
-    my $class = $self->mb_class;
-    
-    return "use $class;";
+#================================================================================================================================================================================================================================================
+sub build {
 }
 
 
-sub register_prereqs {
-# don't add additional prepreqs as we are in JS land already
-}
-
-
-sub test {
-# do nothing currently
-
-#  my ($self, $target) = @_;
-#
-#  $self->build;
-#  system($^X, 'Build', 'test') and die "error running $^X Build test\n";
-#
-#  return;
-}
-
-
-#==================================================================================================
-# Copied from Dist::Zilla::Plugin::MetaJSON
-
-with 'Dist::Zilla::Role::FileGatherer';
-
-use CPAN::Meta::Converter 2.101550; # improved downconversion
-use CPAN::Meta::Validator 2.101550; # improved downconversion
-use Dist::Zilla::File::FromCode;
-use Hash::Merge::Simple ();
-use JSON 2;
-
-
-has version => (
-  is  => 'ro',
-  isa => 'Num',
-  default => '1.4',
-);
-
-
-sub add_meta_json {
-  my ($self, $arg) = @_;
-
-  my $zilla = $self->zilla;
-
-  my $file  = Dist::Zilla::File::FromCode->new({
-    name => 'META.json',
-    code => sub {
-      my $distmeta  = $zilla->distmeta;
-
-      my $validator = CPAN::Meta::Validator->new($distmeta);
-
-      unless ($validator->is_valid) {
-        my $msg = "Invalid META structure.  Errors found:\n";
-        $msg .= join( "\n", $validator->errors );
-        $self->log_fatal($msg);
-      }
-
-      my $converter = CPAN::Meta::Converter->new($distmeta);
-      
-      my $output    = $converter->convert(version => $self->version);
-      
-      # the solely purpose of the copy-paste from Dist::Zilla::Plugin::MetaJSON
-      $output->{ static_dir } = $self->static_dir;
-      
-      if ($output->{ requires }) {
-          $output->{ requires } = $self->replace_colons_with_dots($output->{ requires } )
-      }
-
-      if ($output->{ build_requires }) {
-          $output->{ build_requires } = $self->replace_colons_with_dots($output->{ build_requires })
-      }
-      
-      
-      JSON->new->ascii(1)->canonical(1)->pretty->encode($output) . "\n";
-    },
-  });
-
-  $self->add_file($file);
-  
-  return;
-}
-
-
-sub replace_colons_with_dots {
-    my ($self, $hash) = @_;
-    
-    my %replaced = map {
-        (my $key = $_) =~ s/::/./g;
-        
-        $key => $hash->{ $_ };
-    } keys %$hash;
-    
-    return \%replaced;
-}
-
-# EOF Copied from Dist::Zilla::Plugin::MetaJSON
-#==================================================================================================
-
-
 #================================================================================================================================================================================================================================================
 sub gather_files {
     my $self = shift;
     
-    $self->add_meta_json();
-    
     my $markup = $self->docs_markup;
     
     my $method = "generate_docs_from_$markup";
@@ -184,7 +69,7 @@ sub generate_docs_from_mmd {
     $self->extract_inlined_docs({
         html => sub {
             my ($comments, $content) = @_;
-            return (Text::MultiMarkdown::markdown($comments), 'html')
+            return (Text::MultiMarkdown::markdown("css: http://bit.ly/multi_markdown_style_css \n\n" . $comments, { document_format => 'Complete' }), 'html')
         },
         
         mmd => sub {
@@ -330,7 +215,7 @@ Dist::Zilla::Plugin::JSAN - a plugin for Dist::Zilla for building JSAN distribut
 
 =head1 VERSION
 
-version 0.01
+version 0.02
 
 =head1 SYNOPSIS
 
@@ -339,7 +224,8 @@ In F<dist.ini>:
     name                = Sample-Dist
     abstract            = Some clever yet compact description
     
-    author              = Clever Guy
+    author              = Clever Guy #1
+    author              = Clever Guy #2
     license             = LGPL_3_0
     copyright_holder    = Clever Guy
     
@@ -348,34 +234,34 @@ In F<dist.ini>:
     [BumpVersionFromGit]
     first_version = 0.01 
     
+    ; include the link to git repo and web page
+    [GithubMeta]
     
     ; choose/generate files to include
     
     [GatherDir]
     [PruneCruft]
-    [ManifestSkip]
     [License]
-
-    
-    ; build system
-    
-    [ExecDir]
-    [ShareDir]
     
     
     ; JSAN-specific configuration
-    [JSAN]                            ; includes META.JSON generation
-    docs_markup         = mmd         ; default
-    static_dir          = static      ; default
+    [JSAN]                          ; generate docs
+    docs_markup         = mmd       ; default
     
     [JSAN::StaticDir]
+    static_dir          = static    ; default
     
-    [JSAN::ReadmeFromMD]              ; should be after docs generation
-    [JSAN::InstallInstructions]       ; add INSTALL file, describing the installation process
-    [JSAN::Bundle]                    ; after docs generation to avoid docs for bundles
+    [JSAN::PkgVersion]
     
-    ; manifest (after all generated files)
-    [Manifest]
+    [JSAN::ReadmeFromMD]            ; should be after docs generation
+    [JSAN::InstallInstructions]     ; add INSTALL file, describing the installation process
+    [JSAN::Bundle]                  ; after docs generation to avoid docs for bundles
+    
+    [JSAN::NPM]
+    main        = lib/Task/Sample/Dist/Core
+    
+    dependency            = joose >= 3.14.0
+    dependency            = json2 >= 0.2.0
     
     
     ; before release
@@ -383,12 +269,11 @@ In F<dist.ini>:
     [Git::Check]
     [CheckChangesHasContent]
     
-    ; [TestRelease] todo
     [ConfirmRelease]
     
     ; releaser
-    [JSAN::Upload]  ; just a no-op for now
-     
+    [JSAN::NPM::Publish]        ; publish in `npm`
+    sudo = 0                    ; default is not to sudo
      
     ; after release
     [Git::Commit / Commit_Dirty_Files]
@@ -404,23 +289,15 @@ In F<dist.ini>:
     push_to = origin
     
     [Twitter]
-    tweet_url     = http://openjsan.org/go/?l={{ '{{ my $dist = $DIST; $dist =~ s/-/./g; $dist; }}' }}
+    tweet_url     = http://cleverguy.github.com/sample-dist/
     tweet         = Released {{ '{{$DIST}}-{{$VERSION}} {{$URL}}' }}
-    hash_tags     = #jsan
-       
-    ; prerequisites
-    
-    [JSAN::Prereq]
-    Joose                         = 3.010
-    Cool.Module                   = 0.01
+    hash_tags     = #nodejs #npm
 
 =head1 DESCRIPTION
 
 This is a plugin for distribution-management tool L<Dist::Zilla>. It greatly simplifies the release process,
 allowing you to focus on the code itself.
 
-As the installer, this plugin use L<Module::Build::JSAN::Installable>.
-
 =head1 PLUGINS
 
 Any usual Dist::Zilla plugins can be used. In the SYNOPSIS above we've used L<Dist::Zilla::Plugin::Git::Check> and L<Dist::Zilla::Plugin::CheckChangesHasContent>.
@@ -432,8 +309,6 @@ L<Dist::Zilla::Plugin::JSAN::InstallInstructions> - generates INSTALL file in th
 
 L<Dist::Zilla::Plugin::JSAN::Bundle> - concatenate individual source files into bundles, based on information from Components.JS file
 
-L<Dist::Zilla::Plugin::JSAN::Prereq> - allows you to specify the dependencies for the distribution, using dot as namespace separator 
-
 L<Dist::Zilla::Plugin::JSAN::StaticDir> - moves the content of the static directory to the distribution folder
 
 =head1 STARTING A NEW DISTRIBUTION
